"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrefixCommandInterceptor = void 0;
const discord_js_1 = require("discord.js");
const rxjs_1 = require("rxjs");
class PrefixCommandInterceptor {
    commandName;
    options;
    constructor(commandName, options = {}) {
        this.commandName = commandName;
        this.options = options;
    }
    intercept(context, next) {
        const message = context.getArgByIndex(0);
        if (!(message instanceof discord_js_1.Message))
            return (0, rxjs_1.throwError)(() => new Error('Prefix command interceptor you can set only for "messageCreate" event'));
        const { isRemoveCommandName = true, isRemovePrefix = true, isIgnoreBotMessage = true, isRemoveMessage = false, prefix = '!', } = this.options;
        if (isIgnoreBotMessage && message.author.bot)
            return (0, rxjs_1.of)(null);
        let messageContent = message.content.trim();
        const messagePrefix = this.getPrefix(messageContent, prefix);
        const commandName = this.getCommandName(messageContent, messagePrefix.length);
        if (messagePrefix !== prefix || commandName !== this.commandName)
            return (0, rxjs_1.of)(null); // not suitable for handler
        if (isRemovePrefix)
            messageContent = messageContent.slice(prefix.length);
        if (isRemoveCommandName)
            messageContent = isRemovePrefix
                ? messageContent.slice(prefix.length + commandName.length)
                : messageContent.substring(0, prefix.length) +
                    messageContent.substring(prefix.length + commandName.length);
        message.content = messageContent.trim();
        return next.handle().pipe((0, rxjs_1.tap)(async () => {
            if (isRemoveMessage)
                await this.removeMessageFromChannel(message);
        }));
    }
    getPrefix(messageContent, prefix) {
        return messageContent.slice(0, prefix.length);
    }
    getCommandName(messageContent, prefixLength) {
        const messageWithoutPrefix = messageContent.slice(prefixLength);
        const command = messageWithoutPrefix.split(' ').shift();
        return command || '';
    }
    async removeMessageFromChannel(message) {
        await message.delete();
    }
}
exports.PrefixCommandInterceptor = PrefixCommandInterceptor;
//# sourceMappingURL=prefix-command.interceptor.js.map